@@ -1,17 +1,8 @@
 import requests
-from bs4 import BeautifulSoup
 import pandas as pd
 import csv
 from lxml import html
 
-# Functions that will be used in recruiting Classes
-def save_html(html, path):
-    with open(path, 'wb') as f:
-        f.write(html)
-def open_html(path):
-    with open(path, 'rb') as f:
-        return f.read()
-
 class Recruit:
 
     def __init__(self):
@@ -95,12 +86,6 @@ class Recruit:
 
         return df
 
-
-
-
-
-
-
 class TransferPortal:
 
     def __init__(self):
